ElementMassContribution

Struct ElementMassContribution 

pub struct ElementMassContribution { /* private fields */ }
A per-element contribution to a formula molar mass.

Implementations

Source

impl ElementMassContribution

pub fn new( symbol: &str, atomic_mass: f64, count: u32, ) -> Result<Self, MolarMassValidationError>

Creates an element mass contribution.

Errors

Returns a molar-mass validation error when the symbol, atomic mass, count, or calculated contribution is invalid.

pub fn symbol(&self) -> &str

Returns the element symbol.

pub const fn atomic_mass(&self) -> f64

Returns the atomic mass in grams per mole.

pub const fn count(&self) -> u32

Returns the element count in the formula.

pub fn total_mass_value(&self) -> f64

Returns the contribution value in grams per mole.

pub fn total_molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>

Returns the contribution as a molar mass value in grams per mole.

Errors

Returns a molar-mass validation error if the calculated contribution is invalid.