MassContributionSet

Struct MassContributionSet 

pub struct MassContributionSet { /* private fields */ }
Ordered per-element molar-mass contributions.

Implementations

Source

impl MassContributionSet

pub const fn new() -> Self

Creates an empty contribution set.

pub fn from_contributions( contributions: impl IntoIterator<Item = ElementMassContribution>, ) -> Self

Creates a contribution set from validated contributions.

pub fn push(&mut self, contribution: ElementMassContribution)

Appends a contribution.

pub fn as_slice(&self) -> &[ElementMassContribution]

Returns the contributions as a slice.

pub fn iter(&self) -> impl Iterator<Item = &ElementMassContribution>

Iterates over contributions in stored order.

pub fn len(&self) -> usize

Returns the number of contributions.

pub fn is_empty(&self) -> bool

Returns true when the contribution set is empty.

pub fn total_mass_value(&self) -> f64

Returns the total molar-mass value in grams per mole.

pub fn molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>

Returns the total as a molar mass value in grams per mole.

Errors

Returns a molar-mass validation error if the total is not finite and positive.