pub struct ElementMassContribution { /* private fields */ }Expand description
A per-element contribution to a formula molar mass.
Implementations
Sourceimpl ElementMassContribution
impl ElementMassContribution
Sourcepub fn new(
symbol: &str,
atomic_mass: f64,
count: u32,
) -> Result<Self, MolarMassValidationError>
pub fn new( symbol: &str, atomic_mass: f64, count: u32, ) -> Result<Self, MolarMassValidationError>
Creates an element mass contribution.
Errors
Returns a molar-mass validation error when the symbol, atomic mass, count, or calculated contribution is invalid.
Sourcepub const fn atomic_mass(&self) -> f64
pub const fn atomic_mass(&self) -> f64
Returns the atomic mass in grams per mole.
Sourcepub fn total_mass_value(&self) -> f64
pub fn total_mass_value(&self) -> f64
Returns the contribution value in grams per mole.
Sourcepub fn total_molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>
pub fn total_molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>
Returns the contribution as a molar mass value in grams per mole.
Errors
Returns a molar-mass validation error if the calculated contribution is invalid.