pub struct MassContributionSet { /* private fields */ }Expand description
Ordered per-element molar-mass contributions.
Implementations
Sourceimpl MassContributionSet
impl MassContributionSet
Sourcepub fn from_contributions(
contributions: impl IntoIterator<Item = ElementMassContribution>,
) -> Self
pub fn from_contributions( contributions: impl IntoIterator<Item = ElementMassContribution>, ) -> Self
Creates a contribution set from validated contributions.
Sourcepub fn push(&mut self, contribution: ElementMassContribution)
pub fn push(&mut self, contribution: ElementMassContribution)
Appends a contribution.
Sourcepub fn as_slice(&self) -> &[ElementMassContribution]
pub fn as_slice(&self) -> &[ElementMassContribution]
Returns the contributions as a slice.
Sourcepub fn iter(&self) -> impl Iterator<Item = &ElementMassContribution>
pub fn iter(&self) -> impl Iterator<Item = &ElementMassContribution>
Iterates over contributions in stored order.
Sourcepub fn total_mass_value(&self) -> f64
pub fn total_mass_value(&self) -> f64
Returns the total molar-mass value in grams per mole.
Sourcepub fn molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>
pub fn molar_mass(&self) -> Result<MolarMass, MolarMassValidationError>
Returns the total as a molar mass value in grams per mole.
Errors
Returns a molar-mass validation error if the total is not finite and positive.